@@ -5,35 +5,29 @@
  */
 
 #include "commentapprovejob.h"
-#include "comment.h"
-#include "bloggerservice.h"
 #include "account.h"
+#include "bloggerservice.h"
+#include "comment.h"
 #include "utils.h"
 
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN CommentApproveJob::Private
 {
-  public:
-    Private(const QString &blogId,
-            const QString &postId,
-            const QString &commentId,
-            ApprovalAction action);
+public:
+    Private(const QString &blogId, const QString &postId, const QString &commentId, ApprovalAction action);
 
-    QString blogId;
-    QString postId;
-    QString commentId;
-    ApprovalAction action;
+    const QString blogId;
+    const QString postId;
+    const QString commentId;
+    const ApprovalAction action;
 };
 
-CommentApproveJob::Private::Private(const QString &blogId_,
-                                    const QString &postId_,
-                                    const QString &commentId_,
-                                    CommentApproveJob::ApprovalAction action_)
+CommentApproveJob::Private::Private(const QString &blogId_, const QString &postId_, const QString &commentId_, CommentApproveJob::ApprovalAction action_)
     : blogId(blogId_)
     , postId(postId_)
     , commentId(commentId_)
@@ -52,16 +46,12 @@ CommentApproveJob::CommentApproveJob(const QString &blogId,
 {
 }
 
-CommentApproveJob::CommentApproveJob(const CommentPtr &comment,
-                                     CommentApproveJob::ApprovalAction action,
-                                     const AccountPtr &account,
-                                     QObject *parent)
+CommentApproveJob::CommentApproveJob(const CommentPtr &comment, CommentApproveJob::ApprovalAction action, const AccountPtr &account, QObject *parent)
     : ModifyJob(account, parent)
     , d(new Private(comment->blogId(), comment->postId(), comment->id(), action))
 {
 }
 
-
 CommentApproveJob::~CommentApproveJob()
 {
     delete d;
@@ -96,4 +86,4 @@ ObjectsList CommentApproveJob::handleReplyWithItems(const QNetworkReply *reply,
     return items;
 }
 
-
+#include "moc_commentapprovejob.cpp"
